Index: /trunk/src/VBox/Main/src-server/RecordingSettingsImpl.cpp
===================================================================
--- /trunk/src/VBox/Main/src-server/RecordingSettingsImpl.cpp	(revision 75366)
+++ /trunk/src/VBox/Main/src-server/RecordingSettingsImpl.cpp	(revision 75367)
@@ -590,6 +590,12 @@
     AutoReadLock alock(this COMMA_LOCKVAL_SRC_POS);
 
-    /* Only allow settings to be changed when recording is disabled. */
-    return m->bd->fEnabled == false;
+    /* Only allow settings to be changed when recording is disabled when the machine is running. */
+    if (   Global::IsOnline(adep.machineState())
+        && m->bd->fEnabled)
+    {
+        return false;
+    }
+
+    return true;
 }
 
